@@ -1,17 +1,18 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
-* Copyright (c) 2018 NetApp, Inc.
-*
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation; either version 2
-* of the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-*/
+ * Copyright (c) 2018 NetApp, Inc.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ */
 
 #include <stdio.h>
 #include <dirent.h>
@@ -21,12 +22,12 @@
 #include <unistd.h>
 #include <errno.h>
 #include <string.h>
-#include <sys/ioctl.h>
 
+#include "common.h"
 #include "nvme.h"
-#include "nvme-ioctl.h"
+#include "libnvme.h"
 
-#include "suffix.h"
+#include "util/suffix.h"
 
 #define CREATE_CMD
 #include "netapp-nvme.h"
@@ -56,17 +57,17 @@ enum {
 static const char *dev_path = "/dev/";
 
 struct smdevice_info {
-	int			nsid;
+	unsigned int		nsid;
 	struct nvme_id_ctrl	ctrl;
 	struct nvme_id_ns	ns;
 	char			dev[265];
 };
 
 struct ontapdevice_info {
-	int			nsid;
+	unsigned int		nsid;
 	struct nvme_id_ctrl	ctrl;
 	struct nvme_id_ns	ns;
-	char			nsdesc[4096];
+	unsigned char		uuid[NVME_UUID_LEN];
 	unsigned char		log_data[ONTAP_C2_LOG_SIZE];
 	char			dev[265];
 };
@@ -102,27 +103,19 @@ static void netapp_nguid_to_str(char *str, __u8 *nguid)
 		str += sprintf(str, "%02x", nguid[i]);
 }
 
-static void netapp_get_ns_size(char *size, long long *lba,
+static void netapp_get_ns_size(char *size, unsigned long long *lba,
 		struct nvme_id_ns *ns)
 {
-	*lba = 1 << ns->lbaf[(ns->flbas & 0x0F)].ds;
+	__u8 lba_index;
+
+	nvme_id_ns_flbas_to_lbaf_inuse(ns->flbas, &lba_index);
+	*lba = 1ULL << ns->lbaf[lba_index].ds;
 	double nsze = le64_to_cpu(ns->nsze) * (*lba);
 	const char *s_suffix = suffix_si_get(&nsze);
 
 	sprintf(size, "%.2f%sB", nsze, s_suffix);
 }
 
-static void netapp_uuid_to_str(char *str, void *data)
-{
-#ifdef LIBUUID
-	uuid_t uuid;
-	struct nvme_ns_id_desc *desc = data;
-
-	memcpy(uuid, data + sizeof(*desc), 16);
-	uuid_unparse_lower(uuid, str);
-#endif
-}
-
 static void ontap_labels_to_str(char *dst, char *src, int count)
 {
 	int i;
@@ -245,10 +238,11 @@ static void netapp_smdevices_print(struct smdevice_info *devices, int count, int
 	char array_label[ARRAY_LABEL_LEN / 2 + 1];
 	char volume_label[VOLUME_LABEL_LEN / 2 + 1];
 	char nguid_str[33];
-	char basestr[] = "%s, Array Name %s, Volume Name %s, NSID %d, "
-			"Volume ID %s, Controller %c, Access State %s, %s\n";
+	char basestr[] =
+	    "%s, Array Name %s, Volume Name %s, NSID %d, Volume ID %s, Controller %c, Access State %s, %s\n";
 	char columnstr[] = "%-16s %-30s %-30s %4d %32s  %c   %-12s %9s\n";
 	char *formatstr = basestr; /* default to "normal" output format */
+	__u8 lba_index;
 
 	if (format == NCOLUMN) {
 		/* for column output, change output string and print column headers */
@@ -261,15 +255,15 @@ static void netapp_smdevices_print(struct smdevice_info *devices, int count, int
 			"------------------------------", "----",
 			"--------------------------------", "----",
 			"------------", "---------");
-	}
-	else if (format == NJSON) {
+	} else if (format == NJSON) {
 		/* prepare for json output */
 		root = json_create_object();
-		json_devices = json_create_object();
+		json_devices = json_create_array();
 	}
 
 	for (i = 0; i < count; i++) {
-		long long int lba = 1 << devices[i].ns.lbaf[(devices[i].ns.flbas & 0x0F)].ds;
+		nvme_id_ns_flbas_to_lbaf_inuse(devices[i].ns.flbas, &lba_index);
+		unsigned long long lba = 1ULL << devices[i].ns.lbaf[lba_index].ds;
 		double nsze = le64_to_cpu(devices[i].ns.nsze) * lba;
 		const char *s_suffix = suffix_si_get(&nsze);
 		char size[128];
@@ -296,6 +290,8 @@ static void netapp_smdevices_print(struct smdevice_info *devices, int count, int
 		/* complete the json output */
 		json_object_add_value_array(root, "SMdevices", json_devices);
 		json_print_object(root, NULL);
+		printf("\n");
+		json_free_object(root);
 	}
 }
 
@@ -306,7 +302,7 @@ static void netapp_ontapdevices_print(struct ontapdevice_info *devices,
 	struct json_object *json_devices = NULL;
 	char vsname[ONTAP_LABEL_LEN] = " ";
 	char nspath[ONTAP_NS_PATHLEN] = " ";
-	long long lba;
+	unsigned long long lba;
 	char size[128];
 	char uuid_str[37] = " ";
 	int i;
@@ -331,13 +327,13 @@ static void netapp_ontapdevices_print(struct ontapdevice_info *devices,
 	} else if (format == NJSON) {
 		/* prepare for json output */
 		root = json_create_object();
-		json_devices = json_create_object();
+		json_devices = json_create_array();
 	}
 
 	for (i = 0; i < count; i++) {
 
 		netapp_get_ns_size(size, &lba, &devices[i].ns);
-		netapp_uuid_to_str(uuid_str, devices[i].nsdesc);
+		nvme_uuid_to_string(devices[i].uuid, uuid_str);
 		netapp_get_ontap_labels(vsname, nspath, devices[i].log_data);
 
 		if (format == NJSON) {
@@ -354,16 +350,18 @@ static void netapp_ontapdevices_print(struct ontapdevice_info *devices,
 		/* complete the json output */
 		json_object_add_value_array(root, "ONTAPdevices", json_devices);
 		json_print_object(root, NULL);
+		printf("\n");
+		json_free_object(root);
 	}
 }
 
 static int nvme_get_ontap_c2_log(int fd, __u32 nsid, void *buf, __u32 buflen)
 {
-	struct nvme_admin_cmd get_log;
+	struct nvme_passthru_cmd get_log;
 	int err;
 
 	memset(buf, 0, buflen);
-	memset(&get_log, 0, sizeof(struct nvme_admin_cmd));
+	memset(&get_log, 0, sizeof(struct nvme_passthru_cmd));
 
 	get_log.opcode = nvme_admin_get_log_page;
 	get_log.nsid = nsid;
@@ -378,7 +376,7 @@ static int nvme_get_ontap_c2_log(int fd, __u32 nsid, void *buf, __u32 buflen)
 	get_log.cdw10 |= ONTAP_C2_LOG_NSINFO_LSP << 8;
 	get_log.cdw11 = numdu;
 
-	err = nvme_submit_admin_passthru(fd, &get_log);
+	err = nvme_submit_admin_passthru(fd, &get_log, NULL);
 	if (err) {
 		fprintf(stderr, "ioctl error %0x\n", err);
 		return 1;
@@ -394,22 +392,26 @@ static int netapp_smdevices_get_info(int fd, struct smdevice_info *item,
 
 	err = nvme_identify_ctrl(fd, &item->ctrl);
 	if (err) {
-		fprintf(stderr, "Identify Controller failed to %s (%s)\n", dev,
-			strerror(err));
+		fprintf(stderr,
+			"Identify Controller failed to %s (%s)\n", dev,
+			err < 0 ? strerror(-err) :
+			nvme_status_to_string(err, false));
 		return 0;
 	}
 
 	if (strncmp("NetApp E-Series", item->ctrl.mn, 15) != 0)
 		return 0; /* not the right model of controller */
 
-	item->nsid = nvme_get_nsid(fd);
-	err = nvme_identify_ns(fd, item->nsid, 0, &item->ns);
+	err = nvme_get_nsid(fd, &item->nsid);
+	err = nvme_identify_ns(fd, item->nsid, &item->ns);
 	if (err) {
-		fprintf(stderr, "Unable to identify namespace for %s (%s)\n",
-			dev, strerror(err));
+		fprintf(stderr,
+			"Unable to identify namespace for %s (%s)\n",
+			dev, err < 0 ? strerror(-err) :
+			nvme_status_to_string(err, false));
 		return 0;
 	}
-	strncpy(item->dev, dev, sizeof(item->dev));
+	strncpy(item->dev, dev, sizeof(item->dev) - 1);
 
 	return 1;
 }
@@ -418,11 +420,13 @@ static int netapp_ontapdevices_get_info(int fd, struct ontapdevice_info *item,
 		const char *dev)
 {
 	int err;
+	void *nsdescs;
 
 	err = nvme_identify_ctrl(fd, &item->ctrl);
 	if (err) {
 		fprintf(stderr, "Identify Controller failed to %s (%s)\n",
-				dev, strerror(err));
+			dev, err < 0 ? strerror(-err) :
+			nvme_status_to_string(err, false));
 		return 0;
 	}
 
@@ -430,30 +434,42 @@ static int netapp_ontapdevices_get_info(int fd, struct ontapdevice_info *item,
 		/* not the right controller model */
 		return 0;
 
-	item->nsid = nvme_get_nsid(fd);
+	err = nvme_get_nsid(fd, &item->nsid);
 
-	err = nvme_identify_ns(fd, item->nsid, 0, &item->ns);
+	err = nvme_identify_ns(fd, item->nsid, &item->ns);
 	if (err) {
 		fprintf(stderr, "Unable to identify namespace for %s (%s)\n",
-				dev, strerror(err));
+			dev, err < 0 ? strerror(-err) :
+			nvme_status_to_string(err, false));
 		return 0;
 	}
 
-	err = nvme_identify_ns_descs(fd, item->nsid, item->nsdesc);
-	if (err) {
-		fprintf(stderr, "Unable to identify namespace descriptor for %s (%s)\n",
-				dev, strerror(err));
+	if (posix_memalign(&nsdescs, getpagesize(), 0x1000)) {
+		fprintf(stderr, "Cannot allocate controller list payload\n");
 		return 0;
 	}
 
+	err = nvme_identify_ns_descs(fd, item->nsid, nsdescs);
+	if (err) {
+		fprintf(stderr, "Unable to identify namespace descriptor for %s (%s)\n",
+			dev, err < 0 ? strerror(-err) :
+			nvme_status_to_string(err, false));
+		free(nsdescs);
+		return 0;
+	}
+
+	memcpy(item->uuid, nsdescs + sizeof(struct nvme_ns_id_desc), sizeof(item->uuid));
+	free(nsdescs);
+
 	err = nvme_get_ontap_c2_log(fd, item->nsid, item->log_data, ONTAP_C2_LOG_SIZE);
 	if (err) {
 		fprintf(stderr, "Unable to get log page data for %s (%s)\n",
-				dev, strerror(err));
+			dev, err < 0 ? strerror(-err) :
+			nvme_status_to_string(err, false));
 		return 0;
 	}
 
-	strncpy(item->dev, dev, sizeof(item->dev));
+	strncpy(item->dev, dev, sizeof(item->dev) - 1);
 
 	return 1;
 }
@@ -537,7 +553,7 @@ static int netapp_smdevices(int argc, char **argv, struct command *command,
 	smdevices = calloc(num, sizeof(*smdevices));
 	if (!smdevices) {
 		fprintf(stderr, "Unable to allocate memory for devices.\n");
-		return ENOMEM;
+		return -ENOMEM;
 	}
 
 	for (i = 0; i < num; i++) {
